@@ -1,8 +1,8 @@
-// SPDX-FileCopyrightText: 2024 Petros Koutsolampros
+// SPDX-FileCopyrightText: 2024-2025 Petros Koutsolampros
 //
 // SPDX-License-Identifier: GPL-3.0-only
 
-#include "communicator.h"
+#include "communicator.hpp"
 
 std::unique_ptr<Communicator> getCommunicator(const bool printProgress) {
     if (printProgress) {
