@@ -10,7 +10,8 @@
 
 Agent::Agent(AgentProgram *program, PointMap *pointmap, int outputMode)
     : m_program(program), m_pointmap(pointmap), m_node(), m_outputMode(outputMode), m_trailNum(-1),
-      m_loc(), m_target(), m_vector(), m_destination(), m_targetPix(), m_occMemory() {}
+      m_loc(), m_target(), m_vector(), m_destination(), m_targetPix(), _padding0(0), _padding1(0),
+      m_occMemory() {}
 
 void Agent::onInit(PixelRef node, int trailNum) {
     m_node = node;
